@@ -1,5 +1,6 @@
+# vim: tabstop=4 shiftwidth=4 softtabstop=4
+
 # Copyright 2013 Hewlett-Packard Development Company, L.P.
-# Copyright 2016 Cray Inc. All rights reserved.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
 #    not use this file except in compliance with the License. You may obtain
@@ -13,20 +14,21 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import json
+import logging
 
-from django.conf import settings
+from django.core import urlresolvers
+from django.core.urlresolvers import reverse_lazy
 from django import template
-from django.urls import reverse
-from django.urls import reverse_lazy
 from django.utils.translation import ugettext_lazy as _  # noqa
-from django.utils.translation import ungettext_lazy
 
 from horizon import tables
 
 from monitoring.alarms import constants
-from monitoring import api
 from monitoring.overview import constants as ov_constants
+from monitoring import api
+
+
+LOG = logging.getLogger(__name__)
 
 
 STATUS = ["OK", "WARNING", "CRITICAL", "UNKNOWN"]
@@ -40,7 +42,7 @@ def get_status(index):
 
 
 def show_status(data):
-    status = data.upper()
+    status = data
     img_tag = '<img src="{img}" title="{label}" class="status-icon" />{label}'
     if status == 'CRITICAL':
         return img_tag.format(img=constants.CRITICAL_ICON, label=status)
@@ -57,18 +59,13 @@ def show_severity(data):
     severity = data['alarm_definition']['severity']
     state = data['state']
     if state == 'ALARM':
-        return severity.upper()
+        return severity
     else:
-        return state.upper()
+        return state
 
 
-def show_alarm_id(data):
-    return data['id']
-
-
-def show_metric_names(data):
-    names = set(metric['name'] for metric in data['metrics'])
-    return ', '.join(names)
+def show_metric_name(data):
+    return data['metrics'][0]['name']
 
 
 def show_def_name(data):
@@ -83,7 +80,7 @@ def show_metric_dimensions(data):
     if len(data['metrics']) > 1:
         commondimensions = data['metrics'][0]['dimensions']
         for metric in data['metrics'][1:]:
-            for k in tuple(commondimensions):
+            for k in commondimensions.keys():
                 if k not in metric['dimensions'].keys() or \
                         commondimensions[k] != metric['dimensions'][k]:
                     del commondimensions[k]
@@ -108,8 +105,9 @@ class ShowAlarmHistory(tables.LinkAction):
     classes = ('btn-edit',)
 
     def get_link_url(self, datum):
-        return reverse(constants.URL_PREFIX + 'history',
-                       args=(datum['alarm_definition']['id'], datum['id'], ))
+        return urlresolvers.reverse(constants.URL_PREFIX + 'history',
+                                    args=(datum['alarm_definition']['id'],
+                                          datum['id'], ))
 
     def allowed(self, request, datum=None):
         return True
@@ -124,8 +122,8 @@ class CreateAlarm(tables.LinkAction):
     ajax = True
 
     def get_link_url(self):
-        return reverse(constants.URL_PREFIX + 'alarm_create',
-                       args=(self.table.kwargs['service'],))
+        return urlresolvers.reverse(constants.URL_PREFIX + 'alarm_create',
+                                    args=(self.table.kwargs['service'],))
 
     def allowed(self, request, datum=None):
         return True
@@ -137,8 +135,9 @@ class EditAlarm(tables.LinkAction):
     classes = ("ajax-modal", "btn-create")
 
     def get_link_url(self, datum):
-        return reverse(constants.URL_PREFIX + 'alarm_edit',
-                       args=(self.table.kwargs['service'], datum['id'], ))
+        return urlresolvers.reverse(constants.URL_PREFIX + 'alarm_edit',
+                                    args=(self.table.kwargs['service'],
+                                          datum['id'], ))
 
     def allowed(self, request, datum=None):
         return True
@@ -154,33 +153,18 @@ class GraphMetric(tables.LinkAction):
         return super(self, GraphMetric).render()
 
     def get_link_url(self, datum):
-        url = ''
-        query = ''
+        name = datum['metrics'][0]['name']
+        threshold = datum['metrics']
+        endpoint = str(reverse_lazy(ov_constants.URL_PREFIX + 'proxy'))
+        endpoint = self.table.request.build_absolute_uri(endpoint)
         self.attrs['target'] = '_blank'
-        try:
-            region = self.table.request.user.services_region
-            grafana_url = getattr(settings, 'GRAFANA_URL').get(region, '')
-            url = grafana_url + \
-                '/dashboard/script/drilldown.js'
-            metric = datum['metrics'][0]['name']
-            dimensions = datum['metrics'][0].get('dimensions', {})
-            query = "?metric=%s" % metric
-            for key, value in dimensions.items():
-                query += "&%s=%s" % (key, value)
-        except AttributeError:
-            # Catches case where Grafana 2 is not enabled.
-            name = datum['metrics'][0]['name']
-            threshold = json.dumps(datum['metrics'])
-            endpoint = str(reverse_lazy(ov_constants.URL_PREFIX + 'proxy'))
-            endpoint = self.table.request.build_absolute_uri(endpoint)
-            url = '/grafana/index.html#/dashboard/script/detail.js'
-            query = "?name=%s&threshold=%s&api=%s" % \
+        url = '/static/grafana/index.html#/dashboard/script/detail.js'
+        query = "?name=%s&threshold=%s&api=%s" % \
                 (name, threshold, endpoint)
         return url + query
 
     def allowed(self, request, datum=None):
-        return (getattr(settings, 'GRAFANA_URL', None) is not None and
-                datum['metrics'])
+        return datum['metrics']
 
 
 class ShowAlarmDefinition(tables.LinkAction):
@@ -190,28 +174,14 @@ class ShowAlarmDefinition(tables.LinkAction):
     def get_link_url(self, datum=None):
         url = 'horizon:monitoring:alarmdefs:alarm_detail'
         args = (datum['alarm_definition']['id'],)
-        return reverse_lazy(url, args=args)
+        return urlresolvers.reverse_lazy(url, args=args)
 
 
 class DeleteAlarm(tables.DeleteAction):
     name = "delete_alarm"
     verbose_name = _("Delete Alarm")
-
-    @staticmethod
-    def action_present(count):
-        return ungettext_lazy(
-            u"Delete Alarm",
-            u"Delete Alarms",
-            count
-        )
-
-    @staticmethod
-    def action_past(count):
-        return ungettext_lazy(
-            u"Deleted Alarm",
-            u"Deleted Alarms",
-            count
-        )
+    data_type_singular = _("Alarm")
+    data_type_plural = _("Alarms")
 
     def allowed(self, request, datum=None):
         return True
@@ -220,19 +190,12 @@ class DeleteAlarm(tables.DeleteAction):
         api.monitor.alarm_delete(request, obj_id)
 
 
-class AlarmsFilterAction(tables.LinkAction):
-    name = "filter"
-    verbose_name = _("Filter Alarms")
-    classes = ("ajax-modal",)
-    icon = "plus"
-    policy_rules = (("alarm", "alarm:filter"),)
-    ajax = True
-
-    def get_link_url(self):
-        return reverse(constants.URL_PREFIX + 'alarm_filter', args=())
-
-    def allowed(self, request, datum=None):
-        return True
+class AlarmsFilterAction(tables.FilterAction):
+    def filter(self, table, alarms, filter_string):
+        """Naive case-insensitive search."""
+        q = filter_string.lower()
+        return [alarm for alarm in alarms
+                if q in alarm['metrics'][0]['name'].lower()]
 
 
 class AlarmsTable(tables.DataTable):
@@ -240,9 +203,8 @@ class AlarmsTable(tables.DataTable):
                           status_choices={(show_status('OK'), True)},
                           filters=[show_status, template.defaultfilters.safe])
     name = tables.Column(transform=show_def_name, verbose_name=_('Name'))
-    alarmId = tables.Column(transform=show_alarm_id, verbose_name=_('Alarm Id'))
-    metrics = tables.Column(transform=show_metric_names,
-                            verbose_name=_('Metric Names'))
+    metrics = tables.Column(transform=show_metric_name,
+                            verbose_name=_('Metric Name'))
     dimensions = tables.Column(transform=show_metric_dimensions,
                                verbose_name=_('Metric Dimensions'))
 
@@ -252,7 +214,7 @@ class AlarmsTable(tables.DataTable):
     def get_object_display(self, obj):
         return obj['id']
 
-    class Meta(object):
+    class Meta:
         name = "alarms"
         verbose_name = _("Alarms")
         row_actions = (GraphMetric,
@@ -271,8 +233,7 @@ def show_timestamp(data):
 
 class AlarmHistoryTable(tables.DataTable):
     timestamp = tables.Column(transform=show_timestamp,
-                              verbose_name=_('Timestamp'),
-                              attrs={"data-type": "timestamp"})
+                              verbose_name=_('Timestamp'))
     old_state = tables.Column('old_state', verbose_name=_('Old State'))
     new_state = tables.Column('new_state', verbose_name=_('New State'))
     alarmDimensions = tables.Column(transform=show_metric_dimensions,
@@ -283,6 +244,6 @@ class AlarmHistoryTable(tables.DataTable):
     def get_object_id(self, obj):
         return obj['alarm_id'] + obj['timestamp']
 
-    class Meta(object):
+    class Meta:
         name = "history"
         verbose_name = _("Alarm History")
